"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var validatorz_1 = require("./validatorz");
exports.createStringValidator = validatorz_1.createStringValidator;
exports.createNumberValidator = validatorz_1.createNumberValidator;
const validatorz_2 = require("./validatorz");
exports.nameValidator = validatorz_2.createStringValidator({
    min: 1,
    max: 40,
    validChars: ["letters", "., "],
});
exports.ageValidator = validatorz_2.createNumberValidator({
    min: 0,
    max: 120,
});
exports.usernameValidator = validatorz_2.createStringValidator({
    min: 3,
    max: 40,
    validChars: ["letters", "digits", "_-"]
});
exports.phoneValidator = validatorz_2.createStringValidator({
    min: 10,
    max: 10,
    validChars: ["digits"],
});
exports.passwordValidator = validatorz_2.createStringValidator({
    mustContain: ["digits", "lowercase", "uppercase", "symbols"],
    min: 8,
    max: 100,
});
exports.emailValidator = validatorz_2.createStringValidator({
    regexp: "^(([^<>()[\\]\\\\.,;:\\s@\"]+(\\.[^<>()[\\]\\\\.,;:\\s@\"]+)*)|(\".+\"))@((\\[[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}])|(([a-zA-Z\\-0-9]+\\.)+[a-zA-Z]{2,}))$",
});
exports.einValidator = validatorz_2.createStringValidator({
    regexp: "^[1-9]\\d?-\\d{7}$",
});
exports.dobValidator = (() => {
    const min = new Date(1900, 1, 0);
    return date => {
        if (!(date instanceof Date)) {
            try {
                date = new Date(date);
            }
            catch (e) {
                return [new Error(`Could not convert ${date} into a date`)];
            }
        }
        if (date < min) {
            return [new Error("Date of birth cannot be before January 1, 1900")];
        }
        if (date > new Date) {
            return [new Error("Date of birth cannot be in the future.")];
        }
        return [];
    };
})();
//# sourceMappingURL=index.js.map